var gltfTutorial = gltfTutorial || {};

(function(gltfTutorial) {

    'use strict';

    var GltfUtils = {

        /**
         * Returns the number of components that an element with the
         * given acessor type has. Valid parameters and their return
         * values are
         * <pre><code>
         * "SCALAR" :  1
         * "VEC2"   :  2
         * "VEC3"   :  3
         * "VEC4"   :  4
         * "MAT2"   :  4
         * "MAT3"   :  9
         * "MAT4"   : 16
         * </code></pre> 
         * For other parameters, the return value is undefined
         * 
         * @param {string} type The accessor.type
         * @return {integer} The number of components 
         */
        getNumComponentsForAccessorType : function(type) {
            switch (type) {
                case "SCALAR": return 1;
                case "VEC2": return 2;
                case "VEC3": return 3;
                case "VEC4": return 4;
                case "MAT2": return 4;
                case "MAT3": return 9;
                case "MAT4": return 16;
            }
            alert("Unknown accessor type: " + type);
            return undefined;
        },

        /**
         * Returns the number of bytes that an element with the
         * given component type consists of. Valid parameters
         * and their return values are
         * <pre><code>
         * BYTE            :  1
         * UNSIGNED_BYTE   :  1
         * SHORT           :  2
         * UNSIGNED_SHORT  :  2
         * INT             :  4
         * UNSIGNED_INT    :  4
         * FLOAT           :  4
         * </code></pre> 
         * For other parameters, the return value is undefined
         * 
         * @param {integer} type The component type
         * @return {integer} The number of bytes 
         */
        getNumBytesForComponentType : function(type) {
            switch (type) {
                case gl.BYTE: return 1;
                case gl.UNSIGNED_BYTE: return 1;
                case gl.SHORT: return 2;
                case gl.UNSIGNED_SHORT: return 2;
                case gl.INT: return 4;
                case gl.UNSIGNED_INT: return 4;
                case gl.FLOAT: return 4;
            }
            alert("Unknown component type: " + type);
            return undefined;
        }
    };
    
    gltfTutorial.GltfUtils = GltfUtils;
    
})(gltfTutorial);

