var gltfTutorial = gltfTutorial || {};


define([
    'GlContext', 
    'IoUtils' , 
    'GltfData' , 
    'RenderedGltf' , 
    'Utils'
], function (
    GlContext,
    GltfData, 
    IoUtils, 
    RenderedGltf, 
    Utils
) {
    
    function startSimpleGltfRenderer() {
    
        console.log("Starting simpleGltfRenderer");

        //var baseUri = "data/UnitSquare/glTF";
        //var gltfFileName = "UnitSquare.gltf";
                
        var baseUri = "data/Duck/glTF";
        var gltfFileName = "Duck.gltf";
            
        var simpleGltfRenderer = new gltfTutorial.SimpleGltfRenderer();
        simpleGltfRenderer.load(baseUri, gltfFileName);
    }
    
    
    (function(gltfTutorial) {
        'use strict';

        var resolveUri = gltfTutorial.IoUtils.resolveUri;
        var loadJsonFile = gltfTutorial.IoUtils.loadJsonFile;
        var GltfData = gltfTutorial.GltfData;
        var GlContext = gltfTutorial.GlContext;
        var RenderedGltf = gltfTutorial.RenderedGltf;
            
    
        /**
         * Constructor of the SimpleGltfRenderer. Obtains the canvas
         * from the document, and creates a GlContext. 
         */
        function SimpleGltfRenderer() {
            var that = this;
            
            this.renderedGltfs = [];
            
            console.log("Creating GL context...");
            this.canvas = document.getElementById("webGlCanvas");
            this.glContext = new GlContext(this.canvas);
            console.log("Creating GL context DONE");
            
            //setInterval(function() { render(); }, 1500);
            
            /**
             * Create a RenderedGltf from the given GltfData. The RenderedGltf
             * will be stored in the renderedGltfs array and initialized. When
             * the initialization is complete, a render pass will be triggered.
             * 
             * @param gltfData {GltfData} The GltfData object that contains
             * the core glTF object, and allows resolving the references to
             * binary data
             */
            function createRenderedGltf(gltfData) {
                
                console.log("Creating rendered glTF");
                
                var renderCallback = function() {
                    render();   
                };
                var renderedGltf = new RenderedGltf(
                    gltfData, that.glContext, renderCallback);
                that.renderedGltfs.push(renderedGltf);
                renderedGltf.init();
            }
        
            /**
             * Render all RenderedGltfs that have been created so far 
             */
            function render() {
                var canvas = that.canvas;
                var glContext = that.glContext;
                var gl = glContext.gl;
        
                gl.viewport(0, 0, canvas.width, canvas.height);
                gl.clear(gl.COLOR_BUFFER_BIT | gl.DEPTH_BUFFER_BIT);
    
                //console.log("Rendering "+renderedGltfs.length);
                that.renderedGltfs.forEach(function(renderedGltf)
                {
                    renderedGltf.render();
                });    
            };
         
            /**
             * Load the glTF from the specified file and render it.
             * 
             * @param baseUri {String} The base URI against which the relative
             * URIs from the glTF will be resolved
             * @param gltfFileName {String} The name of the main glTF file 
             */
            SimpleGltfRenderer.prototype.load = function(baseUri, gltfFileName) {
                var uri = resolveUri(baseUri, gltfFileName);
                
                console.log("Loading from "+uri);
                
                // Load the glTF JSON, and create a GltfData object, which
                // combines the glTF and the binary data that is referred
                // to. This GltfData is then passed to createRenderedGltf
                loadJsonFile(uri).then(function(gltf) {
                    var gltfData = new GltfData(baseUri, gltf);
                    createRenderedGltf(gltfData);
                });
            };
            
        };
    
        gltfTutorial.SimpleGltfRenderer = SimpleGltfRenderer;
    
    })(gltfTutorial);
    
    startSimpleGltfRenderer();
});


